@@ -4,12 +4,18 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.044 qw(:Status);
+use IO::Compress::Base::Common 2.047 qw(:Status);
+use Compress::Raw::Zlib  2.047 qw( !crc32 !adler32 ) ;
+                                  
+require Exporter;                                     
+our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, @EXPORT, %DEFLATE_CONSTANTS);
 
-use Compress::Raw::Zlib  2.044 qw(Z_OK Z_FINISH MAX_WBITS) ;
-our ($VERSION);
-
-$VERSION = '2.044';
+$VERSION = '2.047';
+@ISA = qw(Exporter);
+@EXPORT_OK = @Compress::Raw::Zlib::DEFLATE_CONSTANTS;
+%EXPORT_TAGS = %Compress::Raw::Zlib::DEFLATE_CONSTANTS;
+@EXPORT = @EXPORT_OK;
+%DEFLATE_CONSTANTS = %EXPORT_TAGS ;
 
 sub mkCompObject
 {
