@@ -1,7 +1,7 @@
 
 package IO::Uncompress::Gunzip ;
 
-require 5.004 ;
+require 5.006 ;
 
 # for RFC1952
 
@@ -9,12 +9,12 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Uncompress::RawInflate 2.044 ;
+use IO::Uncompress::RawInflate 2.047 ;
 
-use Compress::Raw::Zlib 2.044 qw( crc32 ) ;
-use IO::Compress::Base::Common 2.044 qw(:Status createSelfTiedObject);
-use IO::Compress::Gzip::Constants 2.044 ;
-use IO::Compress::Zlib::Extra 2.044 ;
+use Compress::Raw::Zlib 2.047 () ;
+use IO::Compress::Base::Common 2.047 qw(:Status createSelfTiedObject);
+use IO::Compress::Gzip::Constants 2.047 ;
+use IO::Compress::Zlib::Extra 2.047 ;
 
 require Exporter ;
 
@@ -28,7 +28,7 @@ Exporter::export_ok_tags('all');
 
 $GunzipError = '';
 
-$VERSION = '2.044';
+$VERSION = '2.047';
 
 sub new
 {
@@ -47,7 +47,7 @@ sub gunzip
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common  2.044 qw(:Parse);
+    use IO::Compress::Base::Common  2.047 qw(:Parse);
     return ( 'ParseExtra' => [1, 1, Parse_boolean,  0] ) ;
 }
 
@@ -222,7 +222,7 @@ sub _readGzipHeader($)
             or return $self->TruncatedHeader("FHCRC");
 
         $HeaderCRC = unpack("v", $buffer) ;
-        my $crc16 = crc32($keep) & 0xFF ;
+        my $crc16 = Compress::Raw::Zlib::crc32($keep) & 0xFF ;
 
         return $self->HeaderError("CRC16 mismatch.")
             if *$self->{Strict} && $crc16 != $HeaderCRC;
@@ -1104,7 +1104,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2011 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2012 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
